Write-Host "Welcome to the Need for Speed Underground PS2 Demo Sound Mod Installation."

$gameDir = Read-Host "Enter the root directory of the game (e.g., C:\Games\NFSU)"
$gameDir = $gameDir.Trim('" ')

# Resolve the provided directory to an absolute path
$gameDir = (Resolve-Path -Path $gameDir).Path

# Check if the resolved directory exists
if (-not (Test-Path -Path $gameDir -PathType Container)) {
    Write-Host "The specified directory does not exist."
    Read-Host "Press Enter to continue..."
    exit
}

# Check if NFSU_icon exists in the selected directory
if (-not (Test-Path -Path (Join-Path $gameDir "NFSU_icon.ico"))) {
    Write-Host "NFSU_icon.ico was not found in the selected directory."
    Write-Host "This is not the game's directory. Please try again."
    Read-Host "Press Enter to continue..."
    exit
}

Write-Host "Game directory set to: $gameDir"

$confirmation = Read-Host "Are you sure you want to install the demo sounds? (Y/N)"
if ($confirmation -ne "Y" -and $confirmation -ne "y") {
    Write-Host "Installation cancelled."
    Read-Host "Press Enter to continue..."
    exit
}


# Define source and destination directories
$sourceDir = Split-Path -Parent $MyInvocation.MyCommand.Path
$turboSourceDir = Join-Path $sourceDir "TURBO"
$nitrousSourceDir = Join-Path $sourceDir "NITROUS"
$menuSourceDir = Join-Path $sourceDir "MENU"
$sparkChatterSourceDir = Join-Path $sourceDir "SPARKCHATTER"
$shiftSourceDir = Join-Path $sourceDir "SHIFT"
$turboDestDir = Join-Path $gameDir "Sound\TURBO"
$nitrousDestDir = Join-Path $gameDir "Sound\NOS"
$menuDestDir = Join-Path $gameDir "Sound\GLOBAL"

# Define backup function
function Backup-File {
    param(
        [string]$filePath
    )
    if (Test-Path -Path $filePath -PathType Leaf) {
        Rename-Item -Path $filePath -NewName ("{0}.bak" -f $filePath)
    }
}

# Move TURBO files
Write-Host "Moving TURBO files..."
Get-ChildItem -Path $turboSourceDir | ForEach-Object {
    $destinationPath = Join-Path $turboDestDir $_.Name
    Write-Host "Moving $($_.Name) to $destinationPath"
    Backup-File -filePath $destinationPath
    Copy-Item -Path $_.FullName -Destination $turboDestDir -Force
}

# Move NITROUS files
Write-Host "Moving NITROUS files..."
Get-ChildItem -Path $nitrousSourceDir | ForEach-Object {
    $destinationPath = Join-Path $nitrousDestDir $_.Name
    Write-Host "Moving $($_.Name) to $destinationPath"
    Backup-File -filePath $destinationPath
    Copy-Item -Path $_.FullName -Destination $nitrousDestDir -Force
}

# Move MENU files
Write-Host "Moving MENU files..."
Get-ChildItem -Path $menuSourceDir | ForEach-Object {
    $destinationPath = Join-Path $menuDestDir $_.Name
    Write-Host "Moving $($_.Name) to $destinationPath"
    Backup-File -filePath $destinationPath
    Copy-Item -Path $_.FullName -Destination $menuDestDir -Force
}

# Move SPARKCHATTER files in ENG_UG_2 and ENG_UG_3
Write-Host "Moving SPARKCHATTER files..."
for ($i = 0; $i -le 3; $i += 1) {
    $carDir = Join-Path $gameDir "Sound\CAR_$i"
    if (Test-Path -Path $carDir -PathType Container) {
        Get-ChildItem -Path $sparkChatterSourceDir | ForEach-Object {
            foreach ($eng in "ENG_UG_2", "ENG_UG_3") {
                $targetDir = Join-Path $carDir $eng
                if (Test-Path -Path $targetDir -PathType Container) {
                    $destinationPath = Join-Path $targetDir $_.Name
                    Write-Host "Moving $($_.Name) to $destinationPath"
                    Backup-File -filePath $destinationPath
                    Copy-Item -Path $_.FullName -Destination $targetDir -Force
                }
            }
        }
    }
}

# Move SHIFT files in ENG_UG_3
Write-Host "Moving SHIFT files..."
for ($i = 0; $i -le 3; $i += 1) {
    $carDir = Join-Path $gameDir "Sound\CAR_$i"
    if (Test-Path -Path $carDir -PathType Container) {
        Get-ChildItem -Path $shiftSourceDir | ForEach-Object {
            $targetDir = Join-Path $carDir "ENG_UG_3"
            if (Test-Path -Path $targetDir -PathType Container) {
                $destinationPath = Join-Path $targetDir $_.Name
                Write-Host "Moving $($_.Name) to $destinationPath"
                Backup-File -filePath $destinationPath
                Copy-Item -Path $_.FullName -Destination $targetDir -Force
            }
        }
    }
}

Write-Host "Installation Complete. Happy vrooming on the streets of Olympic City!"
Read-Host " "