Write-Host "Welcome to the Need for Speed Underground PS2 Demo Sound Mod Uninstallation."

$gameDir = Read-Host "Enter the root directory of the game (e.g., C:\Games\NFSU)"
$gameDir = $gameDir.Trim('" ')

# Resolve the provided directory to an absolute path
$gameDir = (Resolve-Path -Path $gameDir).Path

# Check if the resolved directory exists
if (-not (Test-Path -Path $gameDir -PathType Container)) {
    Write-Host "The specified directory does not exist."
    Read-Host "Press Enter to continue..."
    exit
}

# Check if NFSU_icon exists in the selected directory
if (-not (Test-Path -Path (Join-Path $gameDir "NFSU_icon.ico"))) {
    Write-Host "NFSU_icon.ico was not found in the selected directory."
    Write-Host "This is not the game's directory. Please try again."
    Read-Host "Press Enter to continue..."
    exit
}

Write-Host "Game directory set to: $gameDir"

$confirmation = Read-Host "Are you sure you want to go vanilla ;) ? (Y/N)"
if ($confirmation -ne "Y" -and $confirmation -ne "y") {
    Write-Host "Uninstallation cancelled."
    Read-Host "Press Enter to continue..."
    exit
}

# Define restore function
function Restore-File {
    param(
        [string]$bakFilePath
    )
    if (Test-Path -Path $bakFilePath -PathType Leaf) {
        $originalFilePath = $bakFilePath -replace '\.bak$'
        Write-Host "Restoring $originalFilePath from $bakFilePath"
        Remove-Item -Path $originalFilePath -Force
        Rename-Item -Path $bakFilePath -NewName $originalFilePath
    }
}

# Restore TURBO files
Write-Host "Restoring TURBO files..."
$turboDestDir = Join-Path $gameDir "Sound\TURBO"
Get-ChildItem -Path $turboDestDir -Filter "*.bak" | ForEach-Object {
    Restore-File -bakFilePath $_.FullName
}

# Restore NITROUS files
Write-Host "Restoring NITROUS files..."
$nitrousDestDir = Join-Path $gameDir "Sound\NOS"
Get-ChildItem -Path $nitrousDestDir -Filter "*.bak" | ForEach-Object {
    Restore-File -bakFilePath $_.FullName
}

# Restore MENU files
Write-Host "Restoring MENU files..."
$menuDestDir = Join-Path $gameDir "Sound\GLOBAL"
Get-ChildItem -Path $menuDestDir -Filter "*.bak" | ForEach-Object {
    Restore-File -bakFilePath $_.FullName
}

# Restore SPARKCHATTER and SHIFT files
$carDirs = @(0..3 | ForEach-Object { Join-Path $gameDir "Sound\CAR_$_" })

Write-Host "Restoring SPARKCHATTER and SHIFT files..."
foreach ($carDir in $carDirs) {
    $sparkChatterTargetDir = Join-Path $carDir "ENG_UG_2"
    $shiftTargetDir = Join-Path $carDir "ENG_UG_3"

    if (Test-Path -Path $sparkChatterTargetDir -PathType Container) {
        Get-ChildItem -Path $sparkChatterTargetDir -Filter "*.bak" | ForEach-Object {
            Restore-File -bakFilePath $_.FullName
        }
    }

    if (Test-Path -Path $shiftTargetDir -PathType Container) {
        Get-ChildItem -Path $shiftTargetDir -Filter "*.bak" | ForEach-Object {
            Restore-File -bakFilePath $_.FullName
        }
    }
}

Write-Host "Uninstallation Complete. Now Get Back On That Wheel and Show Them How It's Done!"
Read-Host " "
